@@ -11,29 +11,36 @@ from yandex_maps import http
 STATIC_MAPS_URL = 'http://static-maps.yandex.ru/1.x/?'
 GEOCODE_URL = 'http://geocode-maps.yandex.ru/1.x/?'
 
-def get_map_url(api_key, longtitude, latitude, zoom, width, height):
+def get_map_url(api_key, longitude, latitude, zoom, width, height):
     ''' returns URL of static yandex map '''
     params = [
-       'll=%0.7f,%0.7f' % (float(longtitude), float(latitude),),
+       'll=%0.7f,%0.7f' % (float(longitude), float(latitude),),
        'size=%d,%d' % (width, height,),
        'z=%d' % zoom,
        'l=map',
-       'pt=%0.7f,%0.7f' % (float(longtitude), float(latitude),),
+       'pt=%0.7f,%0.7f' % (float(longitude), float(latitude),),
        'key=%s' % api_key
     ]
     return STATIC_MAPS_URL + '&'.join(params)
 
 def geocode(api_key, address, timeout=2):
     ''' returns (longtitude, latitude,) tuple for given address '''
+    try:
+        xml = _get_geocode_xml(api_key, address, timeout)
+        return _get_coords(xml)
+    except IOError:
+        return None, None
+
+def _get_geocode_xml(api_key, address, timeout=2):
+    url = _get_geocode_url(api_key, address)
+    status_code, response = http.request('GET', url, timeout=timeout)
+    return response
+
+def _get_geocode_url(api_key, address):
     if isinstance(address, unicode):
         address = address.encode('utf8')
     params = urllib.urlencode({'geocode': address, 'key': api_key})
-    url = GEOCODE_URL + params
-    try:
-        status_code, response = http.request('GET', url, timeout=timeout)
-    except IOError:
-        return None, None
-    return _get_coords(response)
+    return GEOCODE_URL + params
 
 def _get_coords(response):
     try:
